﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace DontHarmDesktop
{
    /// <summary>
    /// Класс для валидации входных данных для сущностей
    /// Функции этого класса возвращают True если данные верны, False если нет
    /// </summary>
    public static class Validation
    {
        public static bool CheckService(string code, decimal price, string name, List<string>errors)
        {
            if (String.IsNullOrEmpty(code))
            {
                errors.Add("Код услуги не заполнен");
            }

            if (String.IsNullOrEmpty(name))
            {
                errors.Add("Наименование услуги не заполнено");
            }

            if (price <= 0)
            {
                errors.Add("Цена не может быть меньше или равна нулю");
            }

            return errors.Count == 0;
        }

        /// <summary>
        /// Сообщает об ошибках через MessageBox
        /// </summary>
        /// <param name="errors">Список ошибок</param>
        public static void DisplayErrors(List<string>errors)
        {
            StringBuilder errorMessage = new StringBuilder();

            errorMessage.AppendLine("Возникли ошибки при проверке даных");
            errorMessage.Append(String.Join(";\n", errors));
            errorMessage.Append(".");

            MessageBox.Show(errorMessage.ToString(), "Ошибки проверки данных", MessageBoxButton.OK, MessageBoxImage.Error);
        }
    }
}
