﻿using DontHarmDesktop.Models;
using Prism.Commands;
using Prism.Mvvm;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace DontHarmDesktop.ViewModels
{
    class ServicesViewModel : BindableBase
    {
        public ObservableCollection<services> Services { get; set; }
        public DelegateCommand AddServiceCmd { get; set; }
        public DelegateCommand EditServiceCmd { get; set; }
        public DelegateCommand DeleteServiceCmd { get; set; }
        public Models.services SelectedService { get; set; }

        public ServicesViewModel()
        {
            var db = new Models.Entities();

            // Сбор услуг, которые не скрыты
            Services = new ObservableCollection<services>(db.services.Where(s => s.hidden == false));

            AddServiceCmd = new DelegateCommand(AddServiceExecuted);
            EditServiceCmd = new DelegateCommand(EditServiceExecuted);
            DeleteServiceCmd = new DelegateCommand(DeleteServiceExecuted);
        }

        /// <summary>
        /// Переходит к странице добавления
        /// </summary>
        private void AddServiceExecuted()
        {
            Navigation.toServiceAdd();
        }

        /// <summary>
        /// Редактирует услугу
        /// </summary>
        private void EditServiceExecuted()
        {
            Navigation.toServiceEdit(SelectedService);
        }

        private void DeleteServiceExecuted()
        {
            // Показать подтверждение
            var response = MessageBox.Show(
                "Вы действительно хотите удалить услугу: " + SelectedService.name + "?",
                "Подтвердите удаление",
                MessageBoxButton.YesNo,
                MessageBoxImage.Question
            );
            
            if (response == MessageBoxResult.No )
            {
                return;
            }

            var db = new Models.Entities();
            var toRemove = db.services.FirstOrDefault(s => s.id == SelectedService.id);
            db.services.Remove(toRemove);
            db.SaveChanges();

            Services.Remove(SelectedService);
        }
    }
}
